parspack

package module
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 26, 2026 License: MIT Imports: 11 Imported by: 0

README

ParsPack for libdns

Go Reference

This package implements the libdns interfaces for ParsPack, allowing you to manage DNS records.

Authentication

  1. You need to a zone (domain) in your ParsPack panel.
  2. Go to CDN Sections and you can see the button for creating a new token.

ParsPack CDN Panel

  1. Create a new API token with the following scopes:

Create API Token Dialog

  • لیست سرویس‌ها
  • لیست رکوردهای DNS
  • ایجاد رکورد DNS
  • آپدیت رکورد DNS
  • حذف رکورد DNS

Example Configuration

p := parspack.Provider{
    APIToken: "your-apitoken-here",
}

Documentation

Overview

Package libdnstemplate implements a DNS record management client compatible with the libdns interfaces for ParsPack.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Provider

type Provider struct {
	APIToken string `json:"api_token,omitempty"`
}

Provider facilitates DNS record manipulation with ParsPack.

func (*Provider) AppendRecords

func (p *Provider) AppendRecords(ctx context.Context, zone string, records []libdns.Record) ([]libdns.Record, error)

AppendRecords adds records to the zone. It returns the records that were added.

func (*Provider) DeleteRecords

func (p *Provider) DeleteRecords(ctx context.Context, zone string, records []libdns.Record) ([]libdns.Record, error)

DeleteRecords deletes the specified records from the zone. It returns the records that were deleted.

func (*Provider) GetRecords

func (p *Provider) GetRecords(ctx context.Context, zone string) ([]libdns.Record, error)

GetRecords lists all the records in the zone.

func (*Provider) ListZones

func (p *Provider) ListZones(ctx context.Context) ([]libdns.Zone, error)

ListZones lists all the zones in the account.

func (*Provider) SetRecords

func (p *Provider) SetRecords(ctx context.Context, zone string, records []libdns.Record) ([]libdns.Record, error)

SetRecords sets the records in the zone, either by updating existing records or creating new ones. It returns the updated records.

Jump to